@@ -117,6 +117,7 @@ items = [
         ("Ext Scroller", "test_external", "edje_external_scroller_clicked"),
         ("Ext Slider", "test_external", "edje_external_slider_clicked"),
         ("Ext Video", "test_external", "edje_external_video_clicked"),
+        ("Ext Icon", "test_external", "edje_external_icon_clicked"),
     ]),
     ("Effects", [
         ("Flip", "test_flip", "flip_clicked"),
@@ -154,8 +155,9 @@ items = [
         ("Icon", "test_icon", "icon_clicked"),
         ("Icon Transparent", "test_icon", "icon_transparent_clicked"),
         ("Icon Standard", "test_icon", "icon_standard_clicked"),
-        ("Image", "test_image", "image_clicked"),
-        ("Image with memfile", "test_image", "image2_clicked"),
+        ("Image", "test_image", "test_image"),
+        ("Image with memfile", "test_image_memfile", "test_image_memfile"),
+        ("Image async load", "test_image_async", "test_image_async"),
         ("Photo", "test_photo", "photo_clicked"),
         ("Photocam", "test_photocam", "photocam_clicked"),
         ("Slideshow", "test_slideshow", "slideshow_clicked"),
@@ -198,7 +200,7 @@ items = [
         ("Themes", "test_theme", "theme_clicked"),
     ]),
     ("Naviframe", [
-        ("Naviframe", "test_naviframe", "naviframe_clicked"),
+        ("Naviframe", "test_naviframe", "test_naviframe"),
     ]),
     ("Popups", [
         ("Ctxpopup", "test_ctxpopup", "ctxpopup_clicked"),
