@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 
 import os, unittest
+import logging
 
 from efl import evas
 from efl import edje
@@ -360,6 +361,7 @@ class TestElementaryExternal(unittest.TestCase):
 
         # TODO test params
 
+    @unittest.skip("Elm Web not maintained atm")
     def testExternalWeb(self):
         elm_web = self.theme.part_external_object_get("ext_elm_web")
         self.assertIsInstance(elm_web, Web)
@@ -368,4 +370,10 @@ class TestElementaryExternal(unittest.TestCase):
 
 
 if __name__ == '__main__':
+    formatter = logging.Formatter("[%(levelname)s] %(name)s (%(filename)s: %(lineno)d) --- %(message)s")
+    handler = logging.StreamHandler()
+    handler.setFormatter(formatter)
+    efllog = logging.getLogger("efl")
+    efllog.addHandler(handler)
+    efllog.setLevel(logging.DEBUG)
     unittest.main(verbosity=2)
