@@ -2,6 +2,7 @@
 # encoding: utf-8
 
 import unittest
+import logging
 
 from efl.eo import Eo
 from efl import elementary
@@ -25,4 +26,10 @@ class TestElmBasics(unittest.TestCase):
         o.delete()
 
 if __name__ == '__main__':
+    formatter = logging.Formatter("[%(levelname)s] %(name)s (%(filename)s: %(lineno)d) --- %(message)s")
+    handler = logging.StreamHandler()
+    handler.setFormatter(formatter)
+    efllog = logging.getLogger("efl")
+    efllog.addHandler(handler)
+    efllog.setLevel(logging.DEBUG)
     unittest.main(verbosity=2)
