@@ -2,6 +2,7 @@
 
 from efl import evas
 import unittest
+import logging
 
 
 def _new_canvas():
@@ -132,4 +133,10 @@ class TestCanvasFactory(unittest.TestCase):
 
 
 if __name__ == '__main__':
+    formatter = logging.Formatter("[%(levelname)s] %(name)s (%(filename)s: %(lineno)d) --- %(message)s")
+    handler = logging.StreamHandler()
+    handler.setFormatter(formatter)
+    efllog = logging.getLogger("efl")
+    efllog.addHandler(handler)
+    efllog.setLevel(logging.DEBUG)
     unittest.main(verbosity=2)
